pub enum RawAttrsOpts<'a> {
    Duration(u32),
    EndReason(u8),
    MedianBefore(f64),
    ReadId(&'a str),
    ReadNumber(i32),
    StartMux(u8),
    StartTime(u64),
}
Provides the Attributes for the Raw Group - which in turn conatins the Signal dataset. This allows us to match for each attribute field, and provide the correct type to HDF5.

Variants

Duration(u32)

The duration of the read in seconds.

EndReason(u8)

The reason that the read stopped.

MedianBefore(f64)

No idea lol

ReadId(&'a str)

37 character UUID-4 identifer for the read.

ReadNumber(i32)

Read number - the number the read is in the run.

StartMux(u8)

Also not sure

StartTime(u64)

The start time of the read in milliseconds (I guess)