Struct frust5_api::MultiFast5File
source · [−]pub struct MultiFast5File { /* private fields */ }Expand description
Struct representing a “Multi” Fast5 file.
Implementations
sourceimpl MultiFast5File
impl MultiFast5File
sourcepub fn new(filename: String, mode: OpenMode) -> MultiFast5File
pub fn new(filename: String, mode: OpenMode) -> MultiFast5File
sourcepub fn create_empty_read(
&mut self,
read_id: String,
run_id: String,
tracking_id: &HashMap<&str, &str>,
context_tags: &HashMap<&str, &str>,
channel_info: ChannelInfo,
raw_attrs: &HashMap<&str, RawAttrsOpts<'_>>,
signal: Vec<i16>
) -> Result<Group, Error>
pub fn create_empty_read(
&mut self,
read_id: String,
run_id: String,
tracking_id: &HashMap<&str, &str>,
context_tags: &HashMap<&str, &str>,
channel_info: ChannelInfo,
raw_attrs: &HashMap<&str, RawAttrsOpts<'_>>,
signal: Vec<i16>
) -> Result<Group, Error>
Diverged from ONT come back and straight up rework Create and empty read group, and populate all the fields for it. MISNOMER - doesn’t return an empty read, returns a populated read.