pub struct MultiFast5File { /* private fields */ }
Struct representing a “Multi” Fast5 file.

Implementations

Create a new MultiFast5 file - for either reading or writing.

Panics
  • Currently if opening for writing and the file already exists, as tries to write attributes that already exist
  • If opening for reading and the file doesn’t already exist.
Examples
use frust5_api::{MultiFast5File. OpenMode}
 
let mut multi = frust5_api::MultiFast5File::new("test.fast5".to_string(), frust5_api::OpenMode::Append);

Diverged from ONT come back and straight up rework Create and empty read group, and populate all the fields for it. MISNOMER - doesn’t return an empty read, returns a populated read.