Struct frust5_api::MultiFast5File
source · [−]pub struct MultiFast5File { /* private fields */ }Expand description
Struct representing a “Multi” Fast5 file.
Implementations
sourceimpl MultiFast5File
impl MultiFast5File
sourcepub fn new(filename: String, mode: OpenMode) -> MultiFast5File
pub fn new(filename: String, mode: OpenMode) -> MultiFast5File
Create a new MultiFast5 file - for either reading or writing.
Panics
- Currently if opening for writing and the file already exists, as tries to write attributes that already exist
- If opening for reading and the file doesn’t already exist.
Examples
use frust5_api::{MultiFast5File. OpenMode}
let mut multi = frust5_api::MultiFast5File::new("test.fast5".to_string(), frust5_api::OpenMode::Append);sourcepub fn create_empty_read(
&mut self,
read_id: String,
run_id: String,
tracking_id: &HashMap<&str, &str>,
context_tags: &HashMap<&str, &str>,
channel_info: ChannelInfo,
raw_attrs: &HashMap<&str, RawAttrsOpts<'_>>
) -> Result<Group, Error>
pub fn create_empty_read(
&mut self,
read_id: String,
run_id: String,
tracking_id: &HashMap<&str, &str>,
context_tags: &HashMap<&str, &str>,
channel_info: ChannelInfo,
raw_attrs: &HashMap<&str, RawAttrsOpts<'_>>
) -> Result<Group, Error>
Diverged from ONT come back and straight up rework Create and empty read group, and populate all the fields for it. MISNOMER - doesn’t return an empty read, returns a populated read.